#
# spec file for package elemental-toolkit
#
# Copyright (c) 2022 - 2023 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

# These variables are coupled to builder scripts
%define commit a9f229102d6e53051d30be38c4f1de03a9fd2ddb
%define c_date 20241002

Name:           elemental-toolkit
VCS: https://src.suse.de/SLFO-pool/elemental-toolkit#d092e23a0003ff8a0b6f595422fc0342d80b3ef63c77cb52eace1ee874e56177
Version:        2.2.1
Release:        160000.2.5
Summary:        The command line client for Elemental
License:        Apache-2.0
Group:          System/Management
Url:            https://github.com/rancher/elemental-toolkit
Source:         %{name}.tar.xz
Patch0:         reproducible-tar.patch

Requires:       dosfstools
Requires:       e2fsprogs
# for blkdeactivate
Requires: lvm2
Requires:       parted
Requires:       rsync
Requires:       udev
Requires:       xfsprogs
Requires:       btrfsprogs
Requires:       snapper
Requires:       xorriso >= 1.5
Requires:       mtools
Requires:       util-linux
Requires:       gptfdisk

%if 0%{?suse_version}
BuildRequires:  golang(API) >= 1.22
BuildRequires:  golang-packaging
%{go_provides}
%else
%global goipath    google.golang.org/api
%global forgeurl   https://github.com/rancher/elemental-toolkit
%global commit     d1ae3f9a425de2618f9058f3b37583ef3ce52c7d
%gometa
%if (0%{?centos_version} == 800) || (0%{?rhel_version} == 800)
BuildRequires:  go1.22
%else
BuildRequires:  compiler(go-compiler)
%endif
%endif
BuildRequires:  xz

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package provides a universal command line client to access
Elemental functionality

%prep
%autosetup -n %{name} -p1

%build

if [ "%{commit}" = "_replaceme_" ]; then
  echo "No commit hash provided"
  exit 1
fi

if [ "%{c_date}" = "_replaceme_" ]; then
  echo "No commit date provided"
  exit 1
fi

export GIT_TAG=$(echo "%{version}" | cut -d "+" -f 1)
GIT_COMMIT=$(echo "%{commit}")
export GIT_COMMIT=${GIT_COMMIT:0:8}
export COMMITDATE="%{c_date}"

make build-cli


%install
mkdir -p %{buildroot}%{_bindir}
install -m755 build/elemental %{buildroot}%{_bindir}

%files
%defattr(-,root,root,-)
%license LICENSE
%{_bindir}/*

%changelog
* Thu Feb 20 2025 bwiedemann@suse.com
- Add reproducible-tar.patch for reproducible builds (boo#1237212, jsc#PED-12137)
* Wed Oct  2 2024 elemental@suse.de
- Update to v2.2.1:
  * a9f22910 Bump yip to v1.9.6
  * 398c0e44 Disable audit package in example Dockerfile
  * 92264f1e  Add cloud-init paths of the new root in 'after-*' hooks (#2192)
  * 491e01b8 Expose max snapshots environment variable (#2193)
* Fri Sep 20 2024 elemental@suse.de
- Update to v2.2.0:
  * 064546f1 Improve state file testing (#2190)
  * 14c049c0 Fix docker build warnings when using buildx
  * 98b0254d Switch to git in OBS (#2187)
  * b1a7dbc6 Bump github.com/containerd/containerd from 1.7.20 to 1.7.22
  * c42a766a Bump k8s.io/mount-utils from 0.31.0 to 0.31.1
  * 8e51d33e Bump golang.org/x/crypto from 0.26.0 to 0.27.0
  * 5a8ecc1c Bump github.com/jaypipes/ghw from 0.12.0 to 0.13.0 (#2178)
  * fa2306d6 Implement state subcommand (#2182)
  * dc52491a Add user defined labels to snapshot info (#2175)
  * b2cce27b Bump github.com/opencontainers/runc in the go_modules group
  * 08a8ead9 Bump k8s.io/mount-utils from 0.30.3 to 0.31.0
  * 949d4709 Bump github.com/docker/docker in the go_modules group
  * 16438ddc Bump github.com/onsi/gomega from 1.34.1 to 1.34.2
  * 1a529527 Bump yip to v1.9.3
  * bbd386ec Bump github.com/onsi/ginkgo/v2 from 2.19.1 to 2.20.2 (#2169)
  * 0cfc891c Bump github.com/google/go-containerregistry from 0.20.1 to
    0.20.2 (#2161)
  * 5e0a28c6 Do not require network in initrd by default
  * 75e17df1 Bump to v2.1.1 for tests and fix recovery test
  * 8dac61cb Disable SELINUX enforcing mode, permissive is the default
  * 265cf018 Add build-disk documentation (#2164)
  * b1bac09c Expose ELEMENTAL_CLOUD_INIT_PATHS option (#2163)
  * b1cc863b Make RAW disks recovery partition expandable (#2159)
  * 44b2e7b5 Bump efi library (#2158)
  * 40b4fd4b Bump github.com/onsi/gomega from 1.34.0 to 1.34.1 (#2157)
  * bfc3696b Bump github.com/google/go-containerregistry from 0.20.0 to
    0.20.1 (#2156)
  * d42f3c8b Bump github.com/onsi/ginkgo/v2 from 2.19.0 to 2.19.1
  * 19a9ae32 Bump github.com/onsi/gomega from 1.33.1 to 1.34.0
  * 3c885d2c Bump github.com/jaypipes/ghw
  * 76caad5f Add test for auto disabled boot entry in Grub
  * 615af35d Bump github.com/bramvdbogaerde/go-scp from 1.4.0 to 1.5.0
  * afe3ed5a Bump github.com/containerd/containerd from 1.7.19 to 1.7.20
  * c9c89b3c Bump k8s.io/mount-utils from 0.30.2 to 0.30.3
  * 51a85a71 Remove unused steps in workflow
  * 80bb6a22 Bump github.com/containerd/containerd from 1.7.18 to 1.7.19
  * f54f6836 Fix cache cleaning for PRs and main pushes (#2144)
  * 396e5aeb Bump golang.org/x/crypto from 0.24.0 to 0.25.0
  * b9fc3e91 Bump github.com/google/go-containerregistry from 0.19.2 to
    0.20.0
  * 644cdc72 Refactor ci (#2137)
  * 22996ef7 Allow insecure registries (#2131)
  * e2feafb9 Bump yip to 1.9.2
  * b41f7d20 Bump tp yip 1.6.2
  * 49ed9afd Bump github.com/bramvdbogaerde/go-scp from 1.2.1 to 1.4.0
  * c7746687 Bump github.com/cenkalti/backoff/v4 from 4.2.1 to 4.3.0
  * b3e17ba2 Bump golang.org/x/crypto from 0.22.0 to 0.24.0
  * 72940f06 Bump github.com/onsi/ginkgo/v2 from 2.17.2 to 2.19.0
  * 3f754032 Bump github.com/containerd/containerd from 1.7.12 to 1.7.18
  * a9bd0f1a Bump github.com/onsi/gomega from 1.30.0 to 1.33.1
  * 884573cd Bump github.com/google/go-containerregistry from 0.19.0 to
    0.19.2
  * 31a8d413 Bump k8s.io/mount-utils from 0.30.1 to 0.30.2
  * 19d2cb04 Bump github.com/spf13/cobra from 1.7.0 to 1.8.1
  * b6a14cf1 Bump github.com/spf13/viper from 1.15.0 to 1.19.0
  * 2b23133c Bump mount utils (#2099)
  * 15a10cc4 Make EFI partition size configurable at install time (#2105)
  * 28c4e473 Use fake mounter in tests
  * 897d872a Ensure subvolume snapshots is mounted to list snapshots
  * 0b9170de Fix smoke test for orange flavor
  * f427491f Update example OSes to more recent versions
  * fc923f42 Remove default network configuration
  * 043a7dfd Add missing glibc-gconv package
  * 9f2f2368 Remove pre-existing Elemental initrds
  * fbe90421 Fix overlaydir setup
  * e20e3829 Move green-rpi flavor to tumbleweed
  * 29e909eb Longer retry during nightly pull
  * 48d6ca48 Refactor and test efi manager
  * 2e56a099 Do not return error for efi.ReadLoadOption
  * fa82c1b1 Fix recovery test (#2086)
  * 8ce930a1 Remove obsolete flags for build-disk command (#2085)
  * a1a22e83 Allow to compile for RPi (#2084)
  * 54664f8c Solve few linter warnings
  * f0d9cb30 Remove the work around for bsc#1210690 and simplify code
  * 5a840145 Bootloader-in-rootfs=true (#2071)
  * 3f96b5e7 Relabel presistent paths only at first boot (#2080)
  * f3d4cfd6 Ensure SELinux relabelling can be disabled in configfile
  * 7686d121 Refine relabel step
  * 3fd2046a Update SELinux docs (#2075)
  * 6c301f2e Move mount config file to /run/elemental
  * a4c414f5 Add extra-cmdline flag to build-iso command (#2072)
  * 1c89db02 SELinux relabel on boot (#2074)
  * c95aa381 Define layout with yaml format
  * d7d208a1 Add branding for live CD (#2065)
  * 6f0b28e1 Set legacy password for upgrade test
  * a5f526d5 Allow key pair of ssh connection in tests
  * 46a88e10 Change default root password
  * f9934d75 Fix error return
  * 22baf14e Fix stackable sources for build-iso (#2061)
  * 786cfa63 Update embedded features docs
  * 4d469e7f Enable SELinux for tumbleweed and green (#2052)
  * 8baaef22 Disable boot entry if efivars is read-only (#2059)
  * 91983af9 Retry pull-toolkit on failure
  * b04f5098 Refactor selinux method (#2057)
  * dddb716b Add autologin feature (#2056)
  * c6b391a8 Move green to tumbleweed
  * c80eaa9b Bump golang.org/x/net in the go_modules group across 1 directory
    (#2051)
  * cccd8387 add symlink for missing binary on ubuntu 22.04+ (#2048)
  * d0ad1014 Document cloud-config-defaults for SELinux support (#2046)
  * 7feca1f4 Make squashfs defaults more consistent
* Mon Aug  5 2024 dcassany@suse.com
- Update to version 2.1.1:
  * [backport] Disable boot entry if efivars is read-only (#2059) (#2145)
  * [backport] CI refactor to v2.1.x branch (#2146)
  * Remove pre-existing Elemental initrds
* Thu Apr 11 2024 fredrik.lonnegren@suse.com
- Update to version 2.1.0:
  * Make squashfs defaults more consistent
  * Snapshottable recovery system (#2032)
  * Change description of boot assessment service (#2037)
  * Remove empty mount paths (#2036)
  * Wait for relevant elemental init stages
  * Fix the fix (#2033)
  * Backwards compatible recovery boot configuration
  * Fix doc typo
  * Iterate over passive snapshots on boot-assessment
  * Skip symlink if kernel already exists (#2028)
  * docs: fix build-iso example (#2026)
  * Update github.com/canonical/go-efilib (#2019)
  * make configurable boot-assessment checks (#2018)
  * Turn off smm test
  * Turn off secure boot test
  * Use 2M firmware args
  * Use secure boot firmware
  * Change test ISO firmware
  * Use ContainSubstring
  * Test qemu secure boot
  * Fix passive snapshots listing in grub.cfg
  * Bump github.com/docker/docker (#2020)
  * Extract recovery kernel (#2016)
  * Change location of bootargs.conf (#2013)
  * Use elemental instead of cos (#2014)
  * Remove flaky assert in downgrade test
  * Bump google.golang.org/protobuf from 1.32.0 to 1.33.0 (#2009)
  * Remove deprecated feature immutable-rootfs (#2007)
  * Bump github.com/docker/docker (#2006)
  * Bump google/go-containerregistry (#2005)
  * Fix downgrade tests, there are no hooks when upgrading from passive
  * Fix version check
  * Fix recovery test
  * Fix downgrade test
  * Use v2.0.0 reference image for tests
  * Switches tests to Ubuntu and KVM for tests
  * Update v2 linker args (#2000)
  * Fix unterminated quoted string (#1999)
  * Tagging for new development version 2.1.0-dev
* Fri Mar 22 2024 dcassany@suse.com
- Update to version 2.0.0:
  * Fix passive snapshots listing in grub.cfg
* Thu Mar 14 2024 dcassany@suse.com
- Update to version 2.0.0:
  * Fix version check
  * Fix recovery test
  * Fix downgrade test
  * Use v2.0.0 reference image for tests
  * Switches tests to Ubuntu and KVM for tests
  * Update v2 linker args (#2000)
  * Fix unterminated quoted string (#1999)
  * Tagging version v2.0.0
  * bump elemental-toolkit to v2 (#1969)
  * Align sysroot mount options with SLE Micro, which in turn is applying default mount options
  * Fix racy workflows
  * Fix build-disk action unit tests
  * Make ext2 the default FS for recovery on disks (#1995)
  * Fix unit tests
  * Use working directory to set the snapper configuration
  * Adding debug messages for snapper configuration
  * Do not migrate legacy images if snapshots are already present (#1990)
  * Fix Recovery only upgrades (#1988)
  * Image variable includes full image path already
  * fix broken link (#1985)
  * Adding snapshotter.type flag install command
  * Add support to /dev/disk/by-path device reference
  * Keep previous behavior for persistent binded paths
  * Add upgrade-recovery subcommand (#1974)
  * Fix grub setup to properly set fallback (#1981)
  * Fix recovery-system.uri env var mapping
  * Fix env vars mapping for install and upgrade commands
  * Relay on the snapshotter setup of the installed system for upgrades (#1979)
  * Fix regression introduced in 547cb932 (#1977)
  * Ensure /run/elemental/efi is RW for upgrades
  * Make snapshotter root dynamic based on the reported mountpoint (#1971)
  * Remove tumbleweed dracut patches (#1964)
  * Regenerate docs
  * Use backup legacy grub.cfg location (#1967)
  * Build toolkit on nightly (#1965)
  * Btrfs snapshotter implementation (#1957)
  * Fix docs publishing error (#1963)
  * Move elemental services to /etc (#1962)
  * Embed file permissions for features (#1961)
  * Improved upgrade test (#1960)
  * Update README workflow
  * Fix workflow dependencies (#1956)
  * Add types for pull_request_target
  * Cleanup packages after build
  * Run zypper clean --all in examples
  * Use pull_request_target
  * Update workflows
  * Umount OEM before switching root
  * Build CLI on changes in go.mod
  * Bump golang(API) to 1.22
  * Update GO_VERSION
  * Update BuildRequires in OBS spec
  * Update copyright year (2024)
  * Use go version 1.22
  * Use at least xorriso 1.5.6
  * Bump the go_modules group across 1 directories with 1 update
  * Add formatting to log message
  * Make linter happy
  * Remove references to old ACTIVE and PASSIVE images
  * Make persistent volume a nested structure of persistent data
  * Add Volumes in Mount spec
  * Prevent unnecessary copy of image tree to tmp folder
  * Install podman in example Dockerfiles
  * Bump github actions (#1933)
  * Add back the BindPath for /oem
  * Bump yip to v1.4.10 (#1926)
  * Remove BindMount for /oem in initramfs stage (#1934)
  * Bump the go_modules group across 1 directories with 1 update (#1932)
  * Add dependabot config (#1929)
  * Refactor to switch to snapshotter interface (#1906)
  * This commit does removes the assumption of a /boot folder
  * Test that persistence is working (#1919)
  * Make mount setup more dynamic based on detected partitions
  * Include elemental partitions in mount command
  * Update dependencies (#1917)
  * Use rancher/yip v1.4.8
  * Imporve support for old boot arguments
  * Bind mount /oem in elemental-setup-initramfs
  * Use v1.3.0 as upgrade base image
  * Install grub.cfg into EFI System Partition (#1904)
  * Bump twpayne/vfs module to latest version
  * Fix license template
  * Include SUT utilities within the repository
  * Mount readonly EFI partition to /run/elemental/efi (#1905)
  * Move grub-config to /etc/elemental
  * Fix partitions typo
  * Change default rootfs feature
  * Update copyright year (2024)
  * Update github.com/go-git/go-git to v5.11.0
  * Add default cloud-init-paths to build commands (#1893)
  * Add loopdevice implementation (#1891)
  * Split arm and x86_64 tests
  * Adding new snapshotter interface
  * Fix typo in Makefile build-rpi-disk target
  * Change trigger to pull_request_target (#1889)
  * Add disable-boot-entry flag to reset-command (#1888)
  * Changes to cleanup-cache workflow (#1887)
  * Make sure the module-setup.sh picks the right paths for systemd units
  * Add permissions to delete cache items
  * Load mount-layout from .env-files (#1885)
  * Drop elemental object and make elemental methods stateless
  * Refactor some elemental package methods to be used as stand alone functions
  * Cleanup caches when PR is closed
  * Add backwards-compatibility for liveCD detection
  * Rename overlay -> ephemeral mounts
  * Fix tumbleweed example
  * Make network configuration part of the example, not defaults
  * Do not run CI on pushes to main, the test already happens on the PR
  * Fix RISCV64 Tumbleweed example build
  * add btrfs support in partitioner
  * Wrap mount.Interface to our own interface (#1875)
  * Update go in build-docs action
  * Refactor early system mounting (#1866)
  * Add force flag in systemd-firstboot yip's plugin so default files are overwritten if they are already existing
  * Make sure it triggers PR workflow
  * Bump yip
  * Add other example distros (#1868)
  * Make lint happy, Runner.error method was unused
  * Log errors of runner commands only in debug mode
  * Fix initrd and kernel ISO paths
  * Refactor grub as a bootloader interface
  * Add target for rpi disk (#1859)
  * Drop ARM32 build
  * Add support for RISC-V 64bit architecture
  * Update golang.org/x/net dependency
  * Remove existing file during build-disk (#1857)
  * Configurable build-disk deploy command
  * Move recovery hostname to cloud-config-defaults
  * Update release workflow
  * Improve CI stability
  * Try different drivers for macOS
  * Add installer test
* Tue Nov 28 2023 dcassany@suse.com
- Update to version 1.1.0+git20231027.9c55b9d7:
  * Use build-disk command (#1847)
  * Make use of partx instead of partprobe
  * build-disk command (#1794)
  * Ensure the cache is renewed on source changes
  * Improve test coverage and fix recovery image label setting
  * Improve state.yaml file loading
  * Remove deprecated cmdline options
  * Fix partitions typo (#1835)
  * Move grub bootargs.cfg into new feature
  * Worflow was still trying to build the already dropped builder image
* Mon Nov 28 2022 kkaempf@suse.com
- elemental-cli needs lvm2 for running blkdeactivate.
* Fri Sep 30 2022 dcassany@suse.com
- Improve requirements in spec
* Fri Sep 23 2022 kkaempf@suse.com
- Update to version 0.0.16+git20220923.0e836a9:
  * Drop binary signature for now (#334)
  * Fix cosign location
  * Fix signatures for binaries and images (#333)
* Fri Sep 23 2022 kkaempf@suse.com
- Update to version 0.0.16+git20220923.075f8ae:
  * Stop testing on image push/release (#332)
  * Remove sanity check for SUSE based systems on efi installation (#331)
  * [auto] Update cmd docs (#328)
* Fri Sep 23 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220923.33d6aba:
  * Rework SetDefaultGrubEntry (#330)
  * Add CreateBootEntry to EFI install/reset (#326)
* Fri Sep 23 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220922.3bfae9c:
  * Add secure boot for EFI ISO images (#327)
* Thu Sep 22 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220922.06e0bbe:
  * [auto] Update cmd docs (#318)
  * Keep working dir after a chroot call (#324)
  * Create ISO for EFI only or BIOS only, not both (#322)
  * Fix image tests to use an up to date system for testing the install (#323)
* Tue Sep 20 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220919.129edf9:
  * Fix disk partitioning (#321)
* Mon Sep 19 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220919.6f62fa2:
  * Rework efi grub install (#317)
  * Include bootloader arrangement in build-iso (#316)
* Mon Sep 12 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220907.0ff8246:
  * Fix GO-2022-0244 (#315)
  * Fix GO-2022-0586 (#314)
* Fri Sep  2 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220831.b488ce7:
  * Bump cosign installer
  * Fix cosign command (#312)
* Wed Aug 31 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220831.efe83cf:
  * Fix image signing (#311)
* Mon Aug 29 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220815.c9a862d:
  * Add extra partitions config on installation (#306)
  * Update docker-master.yaml
* Thu Aug 11 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220811.07f8e36:
  * Drop luet init from BuildConfig (#310)
  * cosign the release artifacts (#308)
  * Fix logging coming from luet (#309)
* Tue Aug  2 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220802.8a7e7a1:
  * Fix branch name for github workflow
  * Push to REPO-ci on master merge (#301)
* Fri Jul 29 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220729.ae4f000:
  * Set the message of what we are setting as default properly (#300)
* Fri Jul 29 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220729.87f0cb4:
  * Allow overriding default grub entry or fallback to default (#299)
  * Log error on upgrade
* Tue Jul 26 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220726.dfb21b4:
  * [auto] Update cmd docs
* Mon Jul 25 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220725.a0b8053:
  * Go mod vendor
  * Unify cmd-line usage
* Thu Jul 21 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220721.be54398:
  * Docker fixes (#289)
* Thu Jul 21 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220721.0f0dccb:
  * [auto] Update cmd docs (#288)
* Wed Jul 20 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220720.2eb14f6:
  * Allow multiple cloud-init files in installation spec (#287)
* Tue Jul 19 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220719.799d323:
  * elemental install: allow to get the EJECT_CD option from the env
* Tue Jul 12 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220707.f1fabd4:
  * Bump yip dependency (#282)
* Wed Jul  6 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220706.d574597:
  * Remove a leftover file (#281)
  * Produce state.yaml files on install, upgrade and reset commands (#278)
* Fri Jun 24 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220622.a81c51f:
  * [auto] Update cmd docs (#274)
  * More improvements to auto Pr (#273)
  * Improve auto docs PR (#271)
  * Set serial tests with ginkgo dsl (#269)
  * Add vendor dir with deps (#266)
  * Fallback to docker type if URI source is of an unknown type (#264)
  * tests: add unit test for CalcFileChecksum
  * build-iso: add computation of the sha256 checksum
  * Add flag to fully disable compression for squashfs (#257)
  * Ensure we properly propagate repository arch configuration in repos (#260)
  * Fix buld-iso (#259)
  * rawdisk: Consume repositories from top level YAML (#255)
  * Bump ghw and fix labels (#253)
  * Fix build-iso command when no arguments are provided (#256)
* Mon Jun 13 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220609.2707687:
  * build-iso: Sanitize config file for build-iso (#251)
  * Fix default config for RawDisk (#249)
  * Long info for build-disk including the SOURCE info (#252)
  * Drop uneeded root test and add mroe tests for syscall (#250)
  * [auto] Update cmd docs (#247)
  * Improve SELinux labeling commands (#245)
  * increase reset test (#241)
  * utils: Drop NewSourceGuessingType() (#242)
  * build-iso: Improve validation for rootfs source image (#234)
  * [auto] Update cmd docs (#240)
  * Split OEM reset from Persistent reset (#239)
  * Relabel SELinux in a chroot env (#230)
* Tue Jun  7 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220606.71c35d2:
  * Fix binary name (#237)
  * Rename package to rancher/elemental-cli (#236)
* Wed Jun  1 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220601.1554b61:
  * Fail disk build if luet errors (#233)
  * Use a channel to close rsync monitoring goroutine (#231)
  * Ensure recovery image file is set according to the filesystem (#229)
  * Add lvm2 to docker image (#227)
  * Bump luet and wire up logger from elemental (#226)
  * Move config fixtures to test/fixtures, add test case (#225)
  * Fix grub-entry-name parsing from config files (#224)
  * Report rsync status (#216)
  * [auto] Update cmd docs (#222)
  * Switch option for using mtree plugin (#208)
* Tue May 31 2022 kkaempf@suse.com
- Update to version 0.0.15+git20220531.7e946eb:
  * Use a channel to close rsync monitoring goroutine (#231)
  * Ensure recovery image file is set according to the filesystem (#229)
  * Add lvm2 to docker image (#227)
  * Bump luet and wire up logger from elemental (#226)
  * Move config fixtures to test/fixtures, add test case (#225)
  * Fix grub-entry-name parsing from config files (#224)
  * Report rsync status (#216)
  * [auto] Update cmd docs (#222)
  * Switch option for using mtree plugin (#208)
  * Deactivate unmounted lvm volumes before partitioning (#221)
* Tue May 24 2022 kkaempf@suse.com
- renamed to elemental-cli
* Tue May 24 2022 kkaempf@suse.com
- Update to version 0.0.14-1+git20220523.605346d:
  * Adding support for additional environment variables to support ros-installer (#217)
  * Use /etc/os-release on install and reset (#218)
  * Use equivalent logic in run and build commands to load configuration (#210)
  * Introduce ReferenceId for Repository (#215)
  * Use litter lib to dump full cfg (#213)
  * Fix passing repositories to luet channel unpack (#214)
  * Fix efi image size calculation (#211)
  * Add arch to config based on current arch (#209)
  * Make use of elemental API in build commands (#207)
  * [auto] Update cmd docs (#206)
  * Refactor runconfig (#189)
* Tue May 24 2022 kkaempf@suse.com
- Update to version 0.0.14-1+git20220517.1a7a85c:
  * [auto] Update cmd docs (#204)
  * Include other configs on config load (#203)
  * Add --local option to install, build-iso, upgrade (#185)
  * Update the system in the dockerfile (#202)
  * [auto] Update cmd docs (#200)
  * Small fix for autogenerated docs
  * Add job to auto create PR for updated docs (#195)
  * Try to fix go cache on CI (#199)
  * Also set temp dir for luet pkgcache (#196)
  * Update go.mod to fix cache (#197)
  * Try to get a decent luet tempdir (#193)
  * Add docs for commands and generator (#192)
  * Protect against wrong squshfs options (#190)
  * Fix loading squash options (#188)
  * Squashfs compression (#187)
  * Set default config dir to /etc/elemental (#181)
  * Introduce generic arch flag for build commands (#182)
  * Fix typo in Config mapstructure mapping (#180)
  * Ensure ISO's defaults are applied (#179)
  * Improve build-iso flags (#177)
  * Use the arch for the repo (#176)
  * Add default values if config is empty (#174)
  * Add build-iso command defaults (#173)
  * Expand build disk (#171)
  * Create basic dir structure for isos with proper permissions (#170)
  * Fix --date default (#169)
  * Add build-disk command (#162)
  * Fix build-iso kernel discovery and root permissions (#168)
  * Exclude only root-located directories (#165)
* Fri May 20 2022 kkaempf@suse.com
- Update to version 0.0.14+git20220519.5766180:
  * Fix efi image size calculation (#211)
  * Add arch to config based on current arch (#209)
* Thu May 19 2022 kkaempf@suse.com
- Update to version 0.0.14+git20220519.de33226:
  * Make use of elemental API in build commands (#207)
  * [auto] Update cmd docs (#206)
  * Refactor runconfig (#189)
  * [auto] Update cmd docs (#204)
  * Include other configs on config load (#203)
  * Add --local option to install, build-iso, upgrade (#185)
* Fri May 13 2022 kkaempf@suse.com
- Update to version 0.0.14+git20220513.4ed4c33:
  * Update the system in the dockerfile (#202)
  * [auto] Update cmd docs (#200)
  * Small fix for autogenerated docs
  * Add job to auto create PR for updated docs (#195)
  * Try to fix go cache on CI (#199)
* Wed May 11 2022 kkaempf@suse.com
- Update to version 0.0.14+git20220511.ce2dd48:
  * Also set temp dir for luet pkgcache (#196)
  * Update go.mod to fix cache (#197)
  * Try to get a decent luet tempdir (#193)
  * Add docs for commands and generator (#192)
* Tue May 10 2022 kkaempf@suse.com
- Update to version 0.0.14+git20220509.2dec7d7:
  * Protect against wrong squshfs options (#190)
  * Fix loading squash options (#188)
  * Squashfs compression (#187)
  * Set default config dir to /etc/elemental (#181)
* Fri May  6 2022 kkaempf@suse.com
- Update to version 0.0.14+git20220504.dc0d414:
  * Introduce generic arch flag for build commands (#182)
* Mon May  2 2022 kkaempf@suse.com
- Update to version 0.0.14+git20220502.62b0cfd:
  * Fix typo in Config mapstructure mapping (#180)
  * Ensure ISO's defaults are applied (#179)
* Thu Apr 28 2022 kkaempf@suse.com
- Update to version 0.0.14+git20220428.49299da:
  * Improve build-iso flags (#177)
  * Use the arch for the repo (#176)
  * Add default values if config is empty (#174)
  * Add build-iso command defaults (#173)
  * Expand build disk (#171)
* Mon Apr 25 2022 kkaempf@suse.com
- Update to version 0.0.14+git20220425.36c1b6a:
  * Create basic dir structure for isos with proper permissions (#170)
  * Fix --date default (#169)
  * Add build-disk command (#162)
  * Fix build-iso kernel discovery and root permissions (#168)
  * Exclude only root-located directories (#165)
  * Properly pass repos to build-iso (#163)
  * Extend LuetInterface to support custom repositories (#161)
  * build-iso command first round implementation (#160)
* Tue Apr 12 2022 kkaempf@suse.com
- Update to version 0.0.13+git20220407.f122839:
  * Move out generic configuration from RunConfig (#159)
* Thu Apr  7 2022 kkaempf@suse.com
- Update to version 0.0.13+git20220405.89d323a:
  * Drop lsblk in favour of ghw library (#155)
  * Add a eject-cd flag for install (#156)
  * Relocate GPT headers for expanded disks (#158)
  * Bump yip to master (#157)
  * Use local context for docker building (#153)
  * Test the docker image install over loop device (#149)
  * Missing one step skipped woops (#152)
  * Dont run tests if only Dockerfile has changed (#151)
  * Move config options into the config package (#148)
  * Add grub2-efi image into the docker image (#150)
  * Remove blkid dependency and limit lsblk usage (#147)
  * Add logger to runner and log commands on debug (#142)
  * Fix docker building on tag (#146)
  * Sync locally build docker names with remote (#145)
  * Fix load and push not being able to be used at the same time (#144)
  * Dockerfile changes (#143)
  * Use auto for FS in upgrade (#141)
  * Keep partition device path after creating a new partition (#140)
  * Adapts action tests to new fs interface (#139)
  * Fix elemental package tests, no root required (#138)
  * Use default dir permissions constant (#137)
  * Fix directory permissions (#136)
* Thu Mar 10 2022 kkaempf@suse.com
- Update to version 0.0.13+git20220310.21e7373:
  * add channel support to install action (#132)
  * Ensure we use configured labels in reset command, not defaults (#133)
  * Check partial yaml unmarshal errors and unify FS (#125)
  * Add dockerfile (#131)
* Wed Mar  9 2022 kkaempf@suse.com
- Update to version 0.0.13+git20220308.f91b2f6:
  * Add checkRoot helper for cmd and add it to root commands (#129)
  * Fix variables initialization in tests (#128)
  * Small fixes (#127)
* Mon Mar  7 2022 kkaempf@suse.com
- Update to version 0.0.13+git20220303.491b27d:
  * Use golangci for lint+license check (#123)
* Tue Mar  1 2022 kkaempf@suse.com
- Update to version 0.0.13+git20220301.c7e1cb7:
  * Use grab library as the http client (#121)
* Fri Feb 25 2022 kkaempf@suse.com
- Update to version 0.0.13+git20220225.dd23b93:
  * Support loop mount on isos (#119)
* Fri Feb 25 2022 kkaempf@suse.com
- Update to version 0.0.13+git20220225.e9b4112:
  * Allow to set GIT_TAG and GIT_COMMIT when calling make (#118)
* Fri Feb 25 2022 kkaempf@suse.com
- Update to version 0.0.13+git20220225.38414ba:
  * Increase shared flags between install, upgrade and reset (#117)
  * Full installation from downloaded ISO (#116)
  * Define all needed images in runconfig (#114)
  * Fixups to upgrade process (#115)
  * CLI fixups (#113)
  * Ensure cloudinit tests can be executed in parallel (#112)
  * Implement yip's Layout plugin using partitioner package (#111)
  * codecov: split cmd from pkg coverage (#109)
  * upgrade: always try to remount state partition (#108)
  * Upgrade fixes for paths and mounts (#107)
* Fri Feb 25 2022 kkaempf@suse.com
- rename to elemental
* Fri Feb 25 2022 kkaempf@suse.com
- Update to version 0.0.13+git20220225.38414ba:
  * Increase shared flags between install, upgrade and reset (#117)
  * Full installation from downloaded ISO (#116)
* Tue Feb 22 2022 kkaempf@suse.com
- Update to version 0.0.12+git20220221.13c2b6f:
  * Define all needed images in runconfig (#114)
  * Fixups to upgrade process (#115)
* Mon Feb 21 2022 kkaempf@suse.com
- Update to version 0.0.12+git20220218.9f1859e:
  * CLI fixups (#113)
  * Ensure cloudinit tests can be executed in parallel (#112)
  * Implement yip's Layout plugin using partitioner package (#111)
  * codecov: split cmd from pkg coverage (#109)
* Thu Feb 17 2022 kkaempf@suse.com
- Update to version 0.0.12+git20220217.a95088a:
  * upgrade: always try to remount state partition (#108)
  * Upgrade fixes for paths and mounts (#107)
  * cli: read target also from config (#106)
  * Upgrade: Fix upgradestateDir (#105)
  * Be more smart about upgrade dir (#104)
  * Refactor CopyActive method to turn tin CopyImage (#95)
  * Create new command (#96)
  * Also check the system label to see if we booting from recovery (#102)
  * Fix upgrade source from channel in recovery (#101)
  * Upgrade: only add mounts for chroot if they have a mountpoint (#100)
  * cloud-init: Process users before SSH (#99)
  * Fix luet not having a logger and changing context (#98)
  * Remove a Focus leftover from action tests (#97)
  * Rework flags to unify some of them (#94)
  * syscall test (#93)
  * Adding CleanStack utility (#92)
* Wed Feb  9 2022 kkaempf@suse.com
- Update to version 0.0.12+git20220209.745468a:
  * Upgrade improvements (#91)
  * Add reset command (#86)
  * upgrade from channel (#81)
  * Ensure make fmt returns error if some file is changed (#90)
  * Changes by running 'make fmt' (#89)
  * Unpack local flag v2 (#87)
  * Add a Chroot.RunCallback method (#84)
  * Make action setup methods public (#83)
  * Install config refactor (#72)
  * Add cache for go modules and build to CI (#76)
  * Rename 'PLabel' form v1.Partition to 'Name' (#74)
  * Move to ginkgo v2 (#73)
  * Add upgrade command (#59)
* Thu Feb  3 2022 kkaempf@suse.com
- Update to version 0.0.12+git20220201.42f728f:
  * Adding incompatible flags tests in install command (#67)
  * Add --reboot and --poweroff flags (#66)
  * Do not use cosign luet plugin (#65)
* Mon Jan 31 2022 kkaempf@suse.com
- Update to version 0.0.12+git20220131.04e7e83:
  * Hide yip errors under debug (#64)
  * Update go.mod (#63)
  * Disable cosign by default (#62)
  * Fixes grub tests flakyness (#61)
  * Ensure RunConfig parameters are writable by Viper (#60)
  * Add retries logic to get devices by label (#57)
  * Add --logfile and --quiet options to root (#56)
  * Add plugin flags to pull-image (#55)
  * Use ext2 FS for images (#54)
  * Adds pull-image (#52)
* Mon Jan 31 2022 kkaempf@suse.com
- Initial version 0.0.12
